@@ -21,7 +21,12 @@ def ngrams(n, tokens):
         tuple or string: A n-gram.
 
     """
-    limit = len(tokens) - n + 1
+    lt = len(tokens)
+
+    if lt < n:
+        yield tokens
+
+    limit = lt - n + 1
 
     for i in range(limit):
         yield tokens[i:i + n]
@@ -30,3 +35,14 @@ def ngrams(n, tokens):
 bigrams = partial(ngrams, 2)
 trigrams = partial(ngrams, 3)
 quadrigrams = partial(ngrams, 4)
+
+
+def join_grams_iter(grams):
+    yield next(grams)
+
+    for g in grams:
+        yield g[-1]
+
+
+def join_ngrams(grams):
+    return ''.join(join_grams_iter(grams))
